#ifndef NT2_INCLUDE_FUNCTIONS_GAMMALN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GAMMALN_HPP_INCLUDED

#include <nt2/euler/include/functions/gammaln.hpp>

#endif
